@@ -2,7 +2,7 @@
 def select_from_list(options):
     from pyfzf.pyfzf import FzfPrompt
     fzf = FzfPrompt()
-    answer = fzf.prompt(options, fzf_options="--cycle --layout reverse --border rounded")
+    answer = fzf.prompt(options, fzf_options="--cycle --layout reverse")
     if len(answer) == 0:
         return None
     return answer[0]
\ No newline at end of file
